==> redshift-0.10.0-sources.jar: software/amazon/awscdk/services/redshift/cloudformation/ClusterParameterGroupResourceProps.java <==
package software.amazon.awscdk.services.redshift.cloudformation;

/**
 * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clusterparametergroup.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.7.6 (build 04cb6bb)", date = "2018-09-27T21:43:53.402Z")
public interface ClusterParameterGroupResourceProps extends software.amazon.jsii.JsiiSerializable {
    /**
     * ``AWS::Redshift::ClusterParameterGroup.Description``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clusterparametergroup.html#cfn-redshift-clusterparametergroup-description
     */
    java.lang.Object getDescription();
    /**
     * ``AWS::Redshift::ClusterParameterGroup.Description``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clusterparametergroup.html#cfn-redshift-clusterparametergroup-description
     */
    void setDescription(final java.lang.String value);
    /**
     * ``AWS::Redshift::ClusterParameterGroup.Description``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clusterparametergroup.html#cfn-redshift-clusterparametergroup-description
     */
    void setDescription(final software.amazon.awscdk.CloudFormationToken value);
    /**
     * ``AWS::Redshift::ClusterParameterGroup.ParameterGroupFamily``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clusterparametergroup.html#cfn-redshift-clusterparametergroup-parametergroupfamily
     */
    java.lang.Object getParameterGroupFamily();
    /**
     * ``AWS::Redshift::ClusterParameterGroup.ParameterGroupFamily``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clusterparametergroup.html#cfn-redshift-clusterparametergroup-parametergroupfamily
     */
    void setParameterGroupFamily(final java.lang.String value);
    /**
     * ``AWS::Redshift::ClusterParameterGroup.ParameterGroupFamily``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clusterparametergroup.html#cfn-redshift-clusterparametergroup-parametergroupfamily
     */
    void setParameterGroupFamily(final software.amazon.awscdk.CloudFormationToken value);
    /**
     * ``AWS::Redshift::ClusterParameterGroup.Parameters``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clusterparametergroup.html#cfn-redshift-clusterparametergroup-parameters
     */
    java.lang.Object getParameters();
    /**
     * ``AWS::Redshift::ClusterParameterGroup.Parameters``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clusterparametergroup.html#cfn-redshift-clusterparametergroup-parameters
     */
    void setParameters(final software.amazon.awscdk.CloudFormationToken value);
    /**
     * ``AWS::Redshift::ClusterParameterGroup.Parameters``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clusterparametergroup.html#cfn-redshift-clusterparametergroup-parameters
     */
    void setParameters(final java.util.List<java.lang.Object> value);
    /**
     * ``AWS::Redshift::ClusterParameterGroup.Tags``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clusterparametergroup.html#cfn-redshift-clusterparametergroup-tags
     */
    java.lang.Object getTags();
    /**
     * ``AWS::Redshift::ClusterParameterGroup.Tags``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clusterparametergroup.html#cfn-redshift-clusterparametergroup-tags
     */
    void setTags(final software.amazon.awscdk.CloudFormationToken value);
    /**
     * ``AWS::Redshift::ClusterParameterGroup.Tags``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clusterparametergroup.html#cfn-redshift-clusterparametergroup-tags
     */
    void setTags(final java.util.List<java.lang.Object> value);

    /**
     * @return a {@link Builder} of {@link ClusterParameterGroupResourceProps}
     */
    static Builder builder() {
        return new Builder();
    }

    /**
     * A builder for {@link ClusterParameterGroupResourceProps}
     */
    final class Builder {
        private java.lang.Object _description;
        private java.lang.Object _parameterGroupFamily;
        @javax.annotation.Nullable
        private java.lang.Object _parameters;
        @javax.annotation.Nullable
        private java.lang.Object _tags;

        /**
         * Sets the value of Description
         * @param value ``AWS::Redshift::ClusterParameterGroup.Description``
         * @return {@code this}
         */
        public Builder withDescription(final java.lang.String value) {
            this._description = java.util.Objects.requireNonNull(value, "description is required");
            return this;
        }
        /**
         * Sets the value of Description
         * @param value ``AWS::Redshift::ClusterParameterGroup.Description``
         * @return {@code this}
         */
        public Builder withDescription(final software.amazon.awscdk.CloudFormationToken value) {
            this._description = java.util.Objects.requireNonNull(value, "description is required");
            return this;
        }
        /**
         * Sets the value of ParameterGroupFamily
         * @param value ``AWS::Redshift::ClusterParameterGroup.ParameterGroupFamily``
         * @return {@code this}
         */
        public Builder withParameterGroupFamily(final java.lang.String value) {
            this._parameterGroupFamily = java.util.Objects.requireNonNull(value, "parameterGroupFamily is required");
            return this;
        }
        /**
         * Sets the value of ParameterGroupFamily
         * @param value ``AWS::Redshift::ClusterParameterGroup.ParameterGroupFamily``
         * @return {@code this}
         */
        public Builder withParameterGroupFamily(final software.amazon.awscdk.CloudFormationToken value) {
            this._parameterGroupFamily = java.util.Objects.requireNonNull(value, "parameterGroupFamily is required");
            return this;
        }
        /**
         * Sets the value of Parameters
         * @param value ``AWS::Redshift::ClusterParameterGroup.Parameters``
         * @return {@code this}
         */
        public Builder withParameters(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
            this._parameters = value;
            return this;
        }
        /**
         * Sets the value of Parameters
         * @param value ``AWS::Redshift::ClusterParameterGroup.Parameters``
         * @return {@code this}
         */
        public Builder withParameters(@javax.annotation.Nullable final java.util.List<java.lang.Object> value) {
            this._parameters = value;
            return this;
        }
        /**
         * Sets the value of Tags
         * @param value ``AWS::Redshift::ClusterParameterGroup.Tags``
         * @return {@code this}
         */
        public Builder withTags(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
            this._tags = value;
            return this;
        }
        /**
         * Sets the value of Tags
         * @param value ``AWS::Redshift::ClusterParameterGroup.Tags``
         * @return {@code this}
         */
        public Builder withTags(@javax.annotation.Nullable final java.util.List<java.lang.Object> value) {
            this._tags = value;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link ClusterParameterGroupResourceProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        public ClusterParameterGroupResourceProps build() {
            return new ClusterParameterGroupResourceProps() {
                private java.lang.Object $description = java.util.Objects.requireNonNull(_description, "description is required");
                private java.lang.Object $parameterGroupFamily = java.util.Objects.requireNonNull(_parameterGroupFamily, "parameterGroupFamily is required");
                @javax.annotation.Nullable
                private java.lang.Object $parameters = _parameters;
                @javax.annotation.Nullable
                private java.lang.Object $tags = _tags;

                @Override
                public java.lang.Object getDescription() {
                    return this.$description;
                }

                @Override
                public void setDescription(final java.lang.String value) {
                    this.$description = java.util.Objects.requireNonNull(value, "description is required");
                }

                @Override
                public void setDescription(final software.amazon.awscdk.CloudFormationToken value) {
                    this.$description = java.util.Objects.requireNonNull(value, "description is required");
                }

                @Override
                public java.lang.Object getParameterGroupFamily() {
                    return this.$parameterGroupFamily;
                }

                @Override
                public void setParameterGroupFamily(final java.lang.String value) {
                    this.$parameterGroupFamily = java.util.Objects.requireNonNull(value, "parameterGroupFamily is required");
                }

                @Override
                public void setParameterGroupFamily(final software.amazon.awscdk.CloudFormationToken value) {
                    this.$parameterGroupFamily = java.util.Objects.requireNonNull(value, "parameterGroupFamily is required");
                }

                @Override
                public java.lang.Object getParameters() {
                    return this.$parameters;
                }

                @Override
                public void setParameters(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
                    this.$parameters = value;
                }

                @Override
                public void setParameters(@javax.annotation.Nullable final java.util.List<java.lang.Object> value) {
                    this.$parameters = value;
                }

                @Override
                public java.lang.Object getTags() {
                    return this.$tags;
                }

                @Override
                public void setTags(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
                    this.$tags = value;
                }

                @Override
                public void setTags(@javax.annotation.Nullable final java.util.List<java.lang.Object> value) {
                    this.$tags = value;
                }

            };
        }
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.redshift.cloudformation.ClusterParameterGroupResourceProps {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
            super(mode);
        }

        /**
         * ``AWS::Redshift::ClusterParameterGroup.Description``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clusterparametergroup.html#cfn-redshift-clusterparametergroup-description
         */
        @Override
        public java.lang.Object getDescription() {
            return this.jsiiGet("description", java.lang.Object.class);
        }

        /**
         * ``AWS::Redshift::ClusterParameterGroup.Description``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clusterparametergroup.html#cfn-redshift-clusterparametergroup-description
         */
        @Override
        public void setDescription(final java.lang.String value) {
            this.jsiiSet("description", java.util.Objects.requireNonNull(value, "description is required"));
        }

        /**
         * ``AWS::Redshift::ClusterParameterGroup.Description``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clusterparametergroup.html#cfn-redshift-clusterparametergroup-description
         */
        @Override
        public void setDescription(final software.amazon.awscdk.CloudFormationToken value) {
            this.jsiiSet("description", java.util.Objects.requireNonNull(value, "description is required"));
        }

        /**
         * ``AWS::Redshift::ClusterParameterGroup.ParameterGroupFamily``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clusterparametergroup.html#cfn-redshift-clusterparametergroup-parametergroupfamily
         */
        @Override
        public java.lang.Object getParameterGroupFamily() {
            return this.jsiiGet("parameterGroupFamily", java.lang.Object.class);
        }

        /**
         * ``AWS::Redshift::ClusterParameterGroup.ParameterGroupFamily``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clusterparametergroup.html#cfn-redshift-clusterparametergroup-parametergroupfamily
         */
        @Override
        public void setParameterGroupFamily(final java.lang.String value) {
            this.jsiiSet("parameterGroupFamily", java.util.Objects.requireNonNull(value, "parameterGroupFamily is required"));
        }

        /**
         * ``AWS::Redshift::ClusterParameterGroup.ParameterGroupFamily``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clusterparametergroup.html#cfn-redshift-clusterparametergroup-parametergroupfamily
         */
        @Override
        public void setParameterGroupFamily(final software.amazon.awscdk.CloudFormationToken value) {
            this.jsiiSet("parameterGroupFamily", java.util.Objects.requireNonNull(value, "parameterGroupFamily is required"));
        }

        /**
         * ``AWS::Redshift::ClusterParameterGroup.Parameters``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clusterparametergroup.html#cfn-redshift-clusterparametergroup-parameters
         */
        @Override
        @javax.annotation.Nullable
        public java.lang.Object getParameters() {
            return this.jsiiGet("parameters", java.lang.Object.class);
        }

        /**
         * ``AWS::Redshift::ClusterParameterGroup.Parameters``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clusterparametergroup.html#cfn-redshift-clusterparametergroup-parameters
         */
        @Override
        public void setParameters(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
            this.jsiiSet("parameters", value);
        }

        /**
         * ``AWS::Redshift::ClusterParameterGroup.Parameters``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clusterparametergroup.html#cfn-redshift-clusterparametergroup-parameters
         */
        @Override
        public void setParameters(@javax.annotation.Nullable final java.util.List<java.lang.Object> value) {
            this.jsiiSet("parameters", value);
        }

        /**
         * ``AWS::Redshift::ClusterParameterGroup.Tags``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clusterparametergroup.html#cfn-redshift-clusterparametergroup-tags
         */
        @Override
        @javax.annotation.Nullable
        public java.lang.Object getTags() {
            return this.jsiiGet("tags", java.lang.Object.class);
        }

        /**
         * ``AWS::Redshift::ClusterParameterGroup.Tags``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clusterparametergroup.html#cfn-redshift-clusterparametergroup-tags
         */
        @Override
        public void setTags(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
            this.jsiiSet("tags", value);
        }

        /**
         * ``AWS::Redshift::ClusterParameterGroup.Tags``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clusterparametergroup.html#cfn-redshift-clusterparametergroup-tags
         */
        @Override
        public void setTags(@javax.annotation.Nullable final java.util.List<java.lang.Object> value) {
            this.jsiiSet("tags", value);
        }
    }
}

==> redshift-0.11.0-sources.jar: software/amazon/awscdk/services/redshift/cloudformation/ClusterParameterGroupResourceProps.java <==
package software.amazon.awscdk.services.redshift.cloudformation;

/**
 * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clusterparametergroup.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.7.7 (build b1c202b)", date = "2018-10-11T17:59:22.537Z")
public interface ClusterParameterGroupResourceProps extends software.amazon.jsii.JsiiSerializable {
    /**
     * ``AWS::Redshift::ClusterParameterGroup.Description``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clusterparametergroup.html#cfn-redshift-clusterparametergroup-description
     */
    java.lang.Object getDescription();
    /**
     * ``AWS::Redshift::ClusterParameterGroup.Description``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clusterparametergroup.html#cfn-redshift-clusterparametergroup-description
     */
    void setDescription(final java.lang.String value);
    /**
     * ``AWS::Redshift::ClusterParameterGroup.Description``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clusterparametergroup.html#cfn-redshift-clusterparametergroup-description
     */
    void setDescription(final software.amazon.awscdk.Token value);
    /**
     * ``AWS::Redshift::ClusterParameterGroup.ParameterGroupFamily``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clusterparametergroup.html#cfn-redshift-clusterparametergroup-parametergroupfamily
     */
    java.lang.Object getParameterGroupFamily();
    /**
     * ``AWS::Redshift::ClusterParameterGroup.ParameterGroupFamily``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clusterparametergroup.html#cfn-redshift-clusterparametergroup-parametergroupfamily
     */
    void setParameterGroupFamily(final java.lang.String value);
    /**
     * ``AWS::Redshift::ClusterParameterGroup.ParameterGroupFamily``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clusterparametergroup.html#cfn-redshift-clusterparametergroup-parametergroupfamily
     */
    void setParameterGroupFamily(final software.amazon.awscdk.Token value);
    /**
     * ``AWS::Redshift::ClusterParameterGroup.Parameters``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clusterparametergroup.html#cfn-redshift-clusterparametergroup-parameters
     */
    java.lang.Object getParameters();
    /**
     * ``AWS::Redshift::ClusterParameterGroup.Parameters``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clusterparametergroup.html#cfn-redshift-clusterparametergroup-parameters
     */
    void setParameters(final software.amazon.awscdk.Token value);
    /**
     * ``AWS::Redshift::ClusterParameterGroup.Parameters``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clusterparametergroup.html#cfn-redshift-clusterparametergroup-parameters
     */
    void setParameters(final java.util.List<java.lang.Object> value);
    /**
     * ``AWS::Redshift::ClusterParameterGroup.Tags``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clusterparametergroup.html#cfn-redshift-clusterparametergroup-tags
     */
    java.lang.Object getTags();
    /**
     * ``AWS::Redshift::ClusterParameterGroup.Tags``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clusterparametergroup.html#cfn-redshift-clusterparametergroup-tags
     */
    void setTags(final software.amazon.awscdk.Token value);
    /**
     * ``AWS::Redshift::ClusterParameterGroup.Tags``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clusterparametergroup.html#cfn-redshift-clusterparametergroup-tags
     */
    void setTags(final java.util.List<java.lang.Object> value);

    /**
     * @return a {@link Builder} of {@link ClusterParameterGroupResourceProps}
     */
    static Builder builder() {
        return new Builder();
    }

    /**
     * A builder for {@link ClusterParameterGroupResourceProps}
     */
    final class Builder {
        private java.lang.Object _description;
        private java.lang.Object _parameterGroupFamily;
        @javax.annotation.Nullable
        private java.lang.Object _parameters;
        @javax.annotation.Nullable
        private java.lang.Object _tags;

        /**
         * Sets the value of Description
         * @param value ``AWS::Redshift::ClusterParameterGroup.Description``
         * @return {@code this}
         */
        public Builder withDescription(final java.lang.String value) {
            this._description = java.util.Objects.requireNonNull(value, "description is required");
            return this;
        }
        /**
         * Sets the value of Description
         * @param value ``AWS::Redshift::ClusterParameterGroup.Description``
         * @return {@code this}
         */
        public Builder withDescription(final software.amazon.awscdk.Token value) {
            this._description = java.util.Objects.requireNonNull(value, "description is required");
            return this;
        }
        /**
         * Sets the value of ParameterGroupFamily
         * @param value ``AWS::Redshift::ClusterParameterGroup.ParameterGroupFamily``
         * @return {@code this}
         */
        public Builder withParameterGroupFamily(final java.lang.String value) {
            this._parameterGroupFamily = java.util.Objects.requireNonNull(value, "parameterGroupFamily is required");
            return this;
        }
        /**
         * Sets the value of ParameterGroupFamily
         * @param value ``AWS::Redshift::ClusterParameterGroup.ParameterGroupFamily``
         * @return {@code this}
         */
        public Builder withParameterGroupFamily(final software.amazon.awscdk.Token value) {
            this._parameterGroupFamily = java.util.Objects.requireNonNull(value, "parameterGroupFamily is required");
            return this;
        }
        /**
         * Sets the value of Parameters
         * @param value ``AWS::Redshift::ClusterParameterGroup.Parameters``
         * @return {@code this}
         */
        public Builder withParameters(@javax.annotation.Nullable final software.amazon.awscdk.Token value) {
            this._parameters = value;
            return this;
        }
        /**
         * Sets the value of Parameters
         * @param value ``AWS::Redshift::ClusterParameterGroup.Parameters``
         * @return {@code this}
         */
        public Builder withParameters(@javax.annotation.Nullable final java.util.List<java.lang.Object> value) {
            this._parameters = value;
            return this;
        }
        /**
         * Sets the value of Tags
         * @param value ``AWS::Redshift::ClusterParameterGroup.Tags``
         * @return {@code this}
         */
        public Builder withTags(@javax.annotation.Nullable final software.amazon.awscdk.Token value) {
            this._tags = value;
            return this;
        }
        /**
         * Sets the value of Tags
         * @param value ``AWS::Redshift::ClusterParameterGroup.Tags``
         * @return {@code this}
         */
        public Builder withTags(@javax.annotation.Nullable final java.util.List<java.lang.Object> value) {
            this._tags = value;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link ClusterParameterGroupResourceProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        public ClusterParameterGroupResourceProps build() {
            return new ClusterParameterGroupResourceProps() {
                private java.lang.Object $description = java.util.Objects.requireNonNull(_description, "description is required");
                private java.lang.Object $parameterGroupFamily = java.util.Objects.requireNonNull(_parameterGroupFamily, "parameterGroupFamily is required");
                @javax.annotation.Nullable
                private java.lang.Object $parameters = _parameters;
                @javax.annotation.Nullable
                private java.lang.Object $tags = _tags;

                @Override
                public java.lang.Object getDescription() {
                    return this.$description;
                }

                @Override
                public void setDescription(final java.lang.String value) {
                    this.$description = java.util.Objects.requireNonNull(value, "description is required");
                }

                @Override
                public void setDescription(final software.amazon.awscdk.Token value) {
                    this.$description = java.util.Objects.requireNonNull(value, "description is required");
                }

                @Override
                public java.lang.Object getParameterGroupFamily() {
                    return this.$parameterGroupFamily;
                }

                @Override
                public void setParameterGroupFamily(final java.lang.String value) {
                    this.$parameterGroupFamily = java.util.Objects.requireNonNull(value, "parameterGroupFamily is required");
                }

                @Override
                public void setParameterGroupFamily(final software.amazon.awscdk.Token value) {
                    this.$parameterGroupFamily = java.util.Objects.requireNonNull(value, "parameterGroupFamily is required");
                }

                @Override
                public java.lang.Object getParameters() {
                    return this.$parameters;
                }

                @Override
                public void setParameters(@javax.annotation.Nullable final software.amazon.awscdk.Token value) {
                    this.$parameters = value;
                }

                @Override
                public void setParameters(@javax.annotation.Nullable final java.util.List<java.lang.Object> value) {
                    this.$parameters = value;
                }

                @Override
                public java.lang.Object getTags() {
                    return this.$tags;
                }

                @Override
                public void setTags(@javax.annotation.Nullable final software.amazon.awscdk.Token value) {
                    this.$tags = value;
                }

                @Override
                public void setTags(@javax.annotation.Nullable final java.util.List<java.lang.Object> value) {
                    this.$tags = value;
                }

            };
        }
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.redshift.cloudformation.ClusterParameterGroupResourceProps {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
            super(mode);
        }

        /**
         * ``AWS::Redshift::ClusterParameterGroup.Description``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clusterparametergroup.html#cfn-redshift-clusterparametergroup-description
         */
        @Override
        public java.lang.Object getDescription() {
            return this.jsiiGet("description", java.lang.Object.class);
        }

        /**
         * ``AWS::Redshift::ClusterParameterGroup.Description``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clusterparametergroup.html#cfn-redshift-clusterparametergroup-description
         */
        @Override
        public void setDescription(final java.lang.String value) {
            this.jsiiSet("description", java.util.Objects.requireNonNull(value, "description is required"));
        }

        /**
         * ``AWS::Redshift::ClusterParameterGroup.Description``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clusterparametergroup.html#cfn-redshift-clusterparametergroup-description
         */
        @Override
        public void setDescription(final software.amazon.awscdk.Token value) {
            this.jsiiSet("description", java.util.Objects.requireNonNull(value, "description is required"));
        }

        /**
         * ``AWS::Redshift::ClusterParameterGroup.ParameterGroupFamily``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clusterparametergroup.html#cfn-redshift-clusterparametergroup-parametergroupfamily
         */
        @Override
        public java.lang.Object getParameterGroupFamily() {
            return this.jsiiGet("parameterGroupFamily", java.lang.Object.class);
        }

        /**
         * ``AWS::Redshift::ClusterParameterGroup.ParameterGroupFamily``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clusterparametergroup.html#cfn-redshift-clusterparametergroup-parametergroupfamily
         */
        @Override
        public void setParameterGroupFamily(final java.lang.String value) {
            this.jsiiSet("parameterGroupFamily", java.util.Objects.requireNonNull(value, "parameterGroupFamily is required"));
        }

        /**
         * ``AWS::Redshift::ClusterParameterGroup.ParameterGroupFamily``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clusterparametergroup.html#cfn-redshift-clusterparametergroup-parametergroupfamily
         */
        @Override
        public void setParameterGroupFamily(final software.amazon.awscdk.Token value) {
            this.jsiiSet("parameterGroupFamily", java.util.Objects.requireNonNull(value, "parameterGroupFamily is required"));
        }

        /**
         * ``AWS::Redshift::ClusterParameterGroup.Parameters``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clusterparametergroup.html#cfn-redshift-clusterparametergroup-parameters
         */
        @Override
        @javax.annotation.Nullable
        public java.lang.Object getParameters() {
            return this.jsiiGet("parameters", java.lang.Object.class);
        }

        /**
         * ``AWS::Redshift::ClusterParameterGroup.Parameters``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clusterparametergroup.html#cfn-redshift-clusterparametergroup-parameters
         */
        @Override
        public void setParameters(@javax.annotation.Nullable final software.amazon.awscdk.Token value) {
            this.jsiiSet("parameters", value);
        }

        /**
         * ``AWS::Redshift::ClusterParameterGroup.Parameters``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clusterparametergroup.html#cfn-redshift-clusterparametergroup-parameters
         */
        @Override
        public void setParameters(@javax.annotation.Nullable final java.util.List<java.lang.Object> value) {
            this.jsiiSet("parameters", value);
        }

        /**
         * ``AWS::Redshift::ClusterParameterGroup.Tags``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clusterparametergroup.html#cfn-redshift-clusterparametergroup-tags
         */
        @Override
        @javax.annotation.Nullable
        public java.lang.Object getTags() {
            return this.jsiiGet("tags", java.lang.Object.class);
        }

        /**
         * ``AWS::Redshift::ClusterParameterGroup.Tags``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clusterparametergroup.html#cfn-redshift-clusterparametergroup-tags
         */
        @Override
        public void setTags(@javax.annotation.Nullable final software.amazon.awscdk.Token value) {
            this.jsiiSet("tags", value);
        }

        /**
         * ``AWS::Redshift::ClusterParameterGroup.Tags``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clusterparametergroup.html#cfn-redshift-clusterparametergroup-tags
         */
        @Override
        public void setTags(@javax.annotation.Nullable final java.util.List<java.lang.Object> value) {
            this.jsiiSet("tags", value);
        }
    }
}
